==> react-link-basic-2.2.0.tgz: package/src/index.js <==
import cx from 'classnames'
import PropTypes from 'prop-types'

import {Link} from '@s-ui/react-router'
import PolymorphicElement from '@s-ui/react-primitive-polymorphic-element'

const renderContent = (icon, literal) =>
  icon && literal ? (
    <span>
      {icon}
      {literal}
    </span>
  ) : (
    literal || icon
  )

export default function LinkBasic({
  as = 'a',
  className,
  disabled,
  handleClick,
  icon,
  literal,
  rel,
  target,
  title,
  useReactRouterLinks,
  url = '#'
}) {
  const BASE_CLASS = 'sui-LinkBasic'
  const linkBasicClassName = cx(BASE_CLASS, className)
  const content = renderContent(icon, literal)
  const isAnchor = as === 'a'
  const commonProps = {
    className: linkBasicClassName,
    rel,
    title
  }
  const anchorProps = {
    href: url,
    target
  }
  const linkProps = {
    target,
    to: url
  }

  const onClick = () => {
    handleClick && handleClick()

    if (!isAnchor) {
      window.location.href = url
    }
  }

  if (disabled) {
    return (
      <span onClick={handleClick} {...commonProps}>
        {content}
      </span>
    )
  }

  if (useReactRouterLinks) {
    return (
      <Link onClick={handleClick} {...commonProps} {...linkProps}>
        {content}
      </Link>
    )
  }

  return (
    <PolymorphicElement
      as={as}
      onClick={onClick}
      {...commonProps}
      {...(isAnchor ? anchorProps : {})}
    >
      {content}
    </PolymorphicElement>
  )
}

LinkBasic.displayName = 'LinkBasic'

LinkBasic.propTypes = {
  as: PropTypes.string,
  className: PropTypes.string,
  disabled: PropTypes.bool,
  handleClick: PropTypes.func,
  icon: PropTypes.element,
  literal: PropTypes.string,
  rel: PropTypes.string,
  target: PropTypes.string,
  title: PropTypes.string,
  url: PropTypes.string,
  useReactRouterLinks: PropTypes.bool
}

==> react-link-basic-2.3.0.tgz: package/src/index.js <==
import cx from 'classnames'
import PropTypes from 'prop-types'

import {Link} from '@s-ui/react-router'
import PolymorphicElement from '@s-ui/react-primitive-polymorphic-element'

const renderContent = (icon, literal) =>
  icon && literal ? (
    <span>
      {icon}
      {literal}
    </span>
  ) : (
    literal || icon
  )

export default function LinkBasic({
  as = 'a',
  className,
  disabled,
  handleClick,
  icon,
  literal,
  rel,
  target,
  title,
  useReactRouterLinks,
  url = '#'
}) {
  const BASE_CLASS = 'sui-LinkBasic'
  const linkBasicClassName = cx(BASE_CLASS, className)
  const content = renderContent(icon, literal)
  const isAnchor = as === 'a'
  const commonProps = {
    className: linkBasicClassName,
    rel,
    title
  }
  const anchorProps = {
    href: url,
    target
  }
  const linkProps = {
    target,
    to: url
  }

  const onClick = event => {
    handleClick && handleClick(event)

    if (!isAnchor) {
      window.location.href = url
    }
  }

  if (disabled) {
    return (
      <span onClick={handleClick} {...commonProps}>
        {content}
      </span>
    )
  }

  if (useReactRouterLinks) {
    return (
      <Link onClick={handleClick} {...commonProps} {...linkProps}>
        {content}
      </Link>
    )
  }

  return (
    <PolymorphicElement
      as={as}
      onClick={onClick}
      {...commonProps}
      {...(isAnchor ? anchorProps : {})}
    >
      {content}
    </PolymorphicElement>
  )
}

LinkBasic.displayName = 'LinkBasic'

LinkBasic.propTypes = {
  as: PropTypes.string,
  className: PropTypes.string,
  disabled: PropTypes.bool,
  handleClick: PropTypes.func,
  icon: PropTypes.element,
  literal: PropTypes.string,
  rel: PropTypes.string,
  target: PropTypes.string,
  title: PropTypes.string,
  url: PropTypes.string,
  useReactRouterLinks: PropTypes.bool
}
